==> pocl_1.1.orig.tar.gz: pocl-1.1/lib/kernel/sleef/libm/rename_vec512.h <==
#define xsin Sleef_sind8_u35_intrin
#define xcos Sleef_cosd8_u35_intrin
#define xsincos Sleef_sincosd8_u35_intrin
#define xtan Sleef_tand8_u35_intrin
#define xasin Sleef_asind8_u35_intrin
#define xacos Sleef_acosd8_u35_intrin
#define xatan Sleef_atand8_u35_intrin
#define xatan2 Sleef_atan2d8_u35_intrin
#define xlog Sleef_logd8_u35_intrin
#define xcbrt Sleef_cbrtd8_u35_intrin
#define xsin_u1 Sleef_sind8_u10_intrin
#define xcos_u1 Sleef_cosd8_u10_intrin
#define xsincos_u1 Sleef_sincosd8_u10_intrin
#define xtan_u1 Sleef_tand8_u10_intrin
#define xasin_u1 Sleef_asind8_u10_intrin
#define xacos_u1 Sleef_acosd8_u10_intrin
#define xatan_u1 Sleef_atand8_u10_intrin
#define xatan2_u1 Sleef_atan2d8_u10_intrin
#define xlog_u1 Sleef_logd8_u10_intrin
#define xcbrt_u1 Sleef_cbrtd8_u10_intrin
#define xexp Sleef_expd8_u10_intrin
#define xpow Sleef_powd8_u10_intrin
#define xsinh Sleef_sinhd8_u10_intrin
#define xcosh Sleef_coshd8_u10_intrin
#define xtanh Sleef_tanhd8_u10_intrin
#define xasinh Sleef_asinhd8_u10_intrin
#define xacosh Sleef_acoshd8_u10_intrin
#define xatanh Sleef_atanhd8_u10_intrin
#define xexp2 Sleef_exp2d8_u10_intrin
#define xexp10 Sleef_exp10d8_u10_intrin
#define xexpm1 Sleef_expm1d8_u10_intrin
#define xlog10 Sleef_log10d8_u10_intrin
#define xlog1p Sleef_log1pd8_u10_intrin
#define xsincospi_u05 Sleef_sincospid8_u05_intrin
#define xsincospi_u35 Sleef_sincospid8_u35_intrin
#define xsinpi_u05 Sleef_sinpid8_u05_intrin
#define xcospi_u05 Sleef_cospid8_u05_intrin
#define xldexp Sleef_ldexpd8_intrin
#define xilogb Sleef_ilogbd8_intrin
#define xfma Sleef_fmad8_intrin
#define xsqrt_u05 Sleef_sqrtd8_u05_intrin
#define xsqrt_u35 Sleef_sqrtd8_u35_intrin
#define xhypot_u05 Sleef_hypotd8_u05_intrin
#define xhypot_u35 Sleef_hypotd8_u35_intrin
#define xfabs Sleef_fabsd8_intrin
#define xcopysign Sleef_copysignd8_intrin
#define xfmax Sleef_fmaxd8_intrin
#define xfmin Sleef_fmind8_intrin
#define xfdim Sleef_fdimd8_intrin
#define xtrunc Sleef_truncd8_intrin
#define xfloor Sleef_floord8_intrin
#define xceil Sleef_ceild8_intrin
#define xround Sleef_roundd8_intrin
#define xrint Sleef_rintd8_intrin
#define xnextafter Sleef_nextafterd8_intrin
#define xfrfrexp Sleef_frfrexpd8_intrin
#define xexpfrexp Sleef_expfrexpd8_intrin
#define xfmod Sleef_fmodd8_intrin
#define xmodf Sleef_modfd8_intrin
#define xlgamma_u1 Sleef_lgammad8_u10_intrin
#define xlgamma_r_u1 Sleef_lgamma_rd8_u10_intrin
#define xtgamma_u1 Sleef_tgammad8_u10_intrin
#define xerf_u1 Sleef_erfd8_u10_intrin
#define xerfc_u15 Sleef_erfcd8_u15_intrin

#define xsinf Sleef_sinf16_u35_intrin
#define xcosf Sleef_cosf16_u35_intrin
#define xsincosf Sleef_sincosf16_u35_intrin
#define xtanf Sleef_tanf16_u35_intrin
#define xasinf Sleef_asinf16_u35_intrin
#define xacosf Sleef_acosf16_u35_intrin
#define xatanf Sleef_atanf16_u35_intrin
#define xatan2f Sleef_atan2f16_u35_intrin
#define xlogf Sleef_logf16_u35_intrin
#define xcbrtf Sleef_cbrtf16_u35_intrin
#define xsinf_u1 Sleef_sinf16_u10_intrin
#define xcosf_u1 Sleef_cosf16_u10_intrin
#define xsincosf_u1 Sleef_sincosf16_u10_intrin
#define xtanf_u1 Sleef_tanf16_u10_intrin
#define xasinf_u1 Sleef_asinf16_u10_intrin
#define xacosf_u1 Sleef_acosf16_u10_intrin
#define xatanf_u1 Sleef_atanf16_u10_intrin
#define xatan2f_u1 Sleef_atan2f16_u10_intrin
#define xlogf_u1 Sleef_logf16_u10_intrin
#define xcbrtf_u1 Sleef_cbrtf16_u10_intrin
#define xexpf Sleef_expf16_u10_intrin
#define xpowf Sleef_powf16_u10_intrin
#define xsinhf Sleef_sinhf16_u10_intrin
#define xcoshf Sleef_coshf16_u10_intrin
#define xtanhf Sleef_tanhf16_u10_intrin
#define xasinhf Sleef_asinhf16_u10_intrin
#define xacoshf Sleef_acoshf16_u10_intrin
#define xatanhf Sleef_atanhf16_u10_intrin
#define xexp2f Sleef_exp2f16_u10_intrin
#define xexp10f Sleef_exp10f16_u10_intrin
#define xexpm1f Sleef_expm1f16_u10_intrin
#define xlog10f Sleef_log10f16_u10_intrin
#define xlog1pf Sleef_log1pf16_u10_intrin
#define xsincospif_u05 Sleef_sincospif16_u05_intrin
#define xsincospif_u35 Sleef_sincospif16_u35_intrin
#define xsinpif_u05 Sleef_sinpif16_u05_intrin
#define xcospif_u05 Sleef_cospif16_u05_intrin
#define xldexpf Sleef_ldexpf16_intrin
#define xilogbf Sleef_ilogbf16_intrin
#define xfmaf Sleef_fmaf16_intrin
#define xsqrtf_u05 Sleef_sqrtf16_u05_intrin
#define xsqrtf_u35 Sleef_sqrtf16_u35_intrin
#define xhypotf_u05 Sleef_hypotf16_u05_intrin
#define xhypotf_u35 Sleef_hypotf16_u35_intrin
#define xfabsf Sleef_fabsf16_intrin
#define xcopysignf Sleef_copysignf16_intrin
#define xfmaxf Sleef_fmaxf16_intrin
#define xfminf Sleef_fminf16_intrin
#define xfdimf Sleef_fdimf16_intrin
#define xtruncf Sleef_truncf16_intrin
#define xfloorf Sleef_floorf16_intrin
#define xceilf Sleef_ceilf16_intrin
#define xroundf Sleef_roundf16_intrin
#define xrintf Sleef_rintf16_intrin
#define xnextafterf Sleef_nextafterf16_intrin
#define xfrfrexpf Sleef_frfrexpf16_intrin
#define xexpfrexpf Sleef_expfrexpf16_intrin
#define xfmodf Sleef_fmodf16_intrin
#define xmodff Sleef_modff16_intrin
#define xlgammaf_u1 Sleef_lgammaf16_u10_intrin
#define xlgamma_rf_u1 Sleef_lgamma_rf16_u10_intrin
#define xtgammaf_u1 Sleef_tgammaf16_u10_intrin
#define xerff_u1 Sleef_erff16_u10_intrin
#define xerfcf_u15 Sleef_erfcf16_u15_intrin
/***********************/
#define xlog1p_fast Sleef_log1p_fast_d8_u10_intrin
#define xlog1pf_fast Sleef_log1p_fast_f16_u10_intrin

#define xpown Sleef_pownd8_u10_intrin
#define xpownf Sleef_pownf16_u10_intrin
#define xpowr Sleef_powrd8_u10_intrin
#define xpowrf Sleef_powrf16_u10_intrin

==> pocl-7.1.tar.gz: pocl-7.1/lib/kernel/sleef/libm/rename_vec512.h <==
#define xsin Sleef_sind8_u35_intrin
#define xcos Sleef_cosd8_u35_intrin
#define xsincos Sleef_sincosd8_u35_intrin
#define xtan Sleef_tand8_u35_intrin
#define xasin Sleef_asind8_u35_intrin
#define xacos Sleef_acosd8_u35_intrin
#define xatan Sleef_atand8_u35_intrin
#define xatan2 Sleef_atan2d8_u35_intrin
#define xlog Sleef_logd8_u35_intrin
#define xcbrt Sleef_cbrtd8_u35_intrin
#define xsin_u1 Sleef_sind8_u10_intrin
#define xcos_u1 Sleef_cosd8_u10_intrin
#define xsincos_u1 Sleef_sincosd8_u10_intrin
#define xtan_u1 Sleef_tand8_u10_intrin
#define xasin_u1 Sleef_asind8_u10_intrin
#define xacos_u1 Sleef_acosd8_u10_intrin
#define xatan_u1 Sleef_atand8_u10_intrin
#define xatan2_u1 Sleef_atan2d8_u10_intrin
#define xlog_u1 Sleef_logd8_u10_intrin
#define xcbrt_u1 Sleef_cbrtd8_u10_intrin
#define xexp Sleef_expd8_u10_intrin
#define xpow Sleef_powd8_u10_intrin
#define xsinh Sleef_sinhd8_u10_intrin
#define xcosh Sleef_coshd8_u10_intrin
#define xtanh Sleef_tanhd8_u10_intrin
#define xasinh Sleef_asinhd8_u10_intrin
#define xacosh Sleef_acoshd8_u10_intrin
#define xatanh Sleef_atanhd8_u10_intrin
#define xexp2 Sleef_exp2d8_u10_intrin
#define xexp10 Sleef_exp10d8_u10_intrin
#define xexpm1 Sleef_expm1d8_u10_intrin
#define xlog10 Sleef_log10d8_u10_intrin
#define xlog2 Sleef_log2d8_u10_intrin
#define xlog1p Sleef_log1pd8_u10_intrin
#define xsincospi_u05 Sleef_sincospid8_u05_intrin
#define xsincospi_u35 Sleef_sincospid8_u35_intrin
#define xsinpi_u05 Sleef_sinpid8_u05_intrin
#define xcospi_u05 Sleef_cospid8_u05_intrin
#define xldexp Sleef_ldexpd8_intrin
#define xilogb Sleef_ilogbd8_intrin
#define xfma Sleef_fmad8_intrin
#define xsqrt Sleef_sqrtd8_intrin
#define xsqrt_u05 Sleef_sqrtd8_u05_intrin
#define xsqrt_u35 Sleef_sqrtd8_u35_intrin
#define xhypot_u05 Sleef_hypotd8_u05_intrin
#define xhypot_u35 Sleef_hypotd8_u35_intrin
#define xfabs Sleef_fabsd8_intrin
#define xcopysign Sleef_copysignd8_intrin
#define xfmax Sleef_fmaxd8_intrin
#define xfmin Sleef_fmind8_intrin
#define xfdim Sleef_fdimd8_intrin
#define xtrunc Sleef_truncd8_intrin
#define xfloor Sleef_floord8_intrin
#define xceil Sleef_ceild8_intrin
#define xround Sleef_roundd8_intrin
#define xrint Sleef_rintd8_intrin
#define xnextafter Sleef_nextafterd8_intrin
#define xfrfrexp Sleef_frfrexpd8_intrin
#define xexpfrexp Sleef_expfrexpd8_intrin
#define xfmod Sleef_fmodd8_intrin
#define xmodf Sleef_modfd8_intrin
#define xlgamma_u1 Sleef_lgammad8_u10_intrin
#define xlgamma_r_u1 Sleef_lgamma_rd8_u10_intrin
#define xtgamma_u1 Sleef_tgammad8_u10_intrin
#define xerf_u1 Sleef_erfd8_u10_intrin
#define xerfc_u15 Sleef_erfcd8_u15_intrin

#define xsinf Sleef_sinf16_u35_intrin
#define xcosf Sleef_cosf16_u35_intrin
#define xsincosf Sleef_sincosf16_u35_intrin
#define xtanf Sleef_tanf16_u35_intrin
#define xasinf Sleef_asinf16_u35_intrin
#define xacosf Sleef_acosf16_u35_intrin
#define xatanf Sleef_atanf16_u35_intrin
#define xatan2f Sleef_atan2f16_u35_intrin
#define xlogf Sleef_logf16_u35_intrin
#define xcbrtf Sleef_cbrtf16_u35_intrin
#define xsinf_u1 Sleef_sinf16_u10_intrin
#define xcosf_u1 Sleef_cosf16_u10_intrin
#define xsincosf_u1 Sleef_sincosf16_u10_intrin
#define xtanf_u1 Sleef_tanf16_u10_intrin
#define xasinf_u1 Sleef_asinf16_u10_intrin
#define xacosf_u1 Sleef_acosf16_u10_intrin
#define xatanf_u1 Sleef_atanf16_u10_intrin
#define xatan2f_u1 Sleef_atan2f16_u10_intrin
#define xlogf_u1 Sleef_logf16_u10_intrin
#define xcbrtf_u1 Sleef_cbrtf16_u10_intrin
#define xexpf Sleef_expf16_u10_intrin
#define xpowf Sleef_powf16_u10_intrin
#define xsinhf Sleef_sinhf16_u10_intrin
#define xcoshf Sleef_coshf16_u10_intrin
#define xtanhf Sleef_tanhf16_u10_intrin
#define xasinhf Sleef_asinhf16_u10_intrin
#define xacoshf Sleef_acoshf16_u10_intrin
#define xatanhf Sleef_atanhf16_u10_intrin
#define xexp2f Sleef_exp2f16_u10_intrin
#define xexp10f Sleef_exp10f16_u10_intrin
#define xexpm1f Sleef_expm1f16_u10_intrin
#define xlog10f Sleef_log10f16_u10_intrin
#define xlog2f Sleef_log2f16_u10_intrin
#define xlog1pf Sleef_log1pf16_u10_intrin
#define xsincospif_u05 Sleef_sincospif16_u05_intrin
#define xsincospif_u35 Sleef_sincospif16_u35_intrin
#define xsinpif_u05 Sleef_sinpif16_u05_intrin
#define xcospif_u05 Sleef_cospif16_u05_intrin
#define xldexpf Sleef_ldexpf16_intrin
#define xilogbf Sleef_ilogbf16_intrin
#define xfmaf Sleef_fmaf16_intrin
#define xsqrtf Sleef_sqrtf16_intrin
#define xsqrtf_u05 Sleef_sqrtf16_u05_intrin
#define xsqrtf_u35 Sleef_sqrtf16_u35_intrin
#define xhypotf_u05 Sleef_hypotf16_u05_intrin
#define xhypotf_u35 Sleef_hypotf16_u35_intrin
#define xfabsf Sleef_fabsf16_intrin
#define xcopysignf Sleef_copysignf16_intrin
#define xfmaxf Sleef_fmaxf16_intrin
#define xfminf Sleef_fminf16_intrin
#define xfdimf Sleef_fdimf16_intrin
#define xtruncf Sleef_truncf16_intrin
#define xfloorf Sleef_floorf16_intrin
#define xceilf Sleef_ceilf16_intrin
#define xroundf Sleef_roundf16_intrin
#define xrintf Sleef_rintf16_intrin
#define xnextafterf Sleef_nextafterf16_intrin
#define xfrfrexpf Sleef_frfrexpf16_intrin
#define xexpfrexpf Sleef_expfrexpf16_intrin
#define xfmodf Sleef_fmodf16_intrin
#define xmodff Sleef_modff16_intrin
#define xlgammaf_u1 Sleef_lgammaf16_u10_intrin
#define xlgamma_rf_u1 Sleef_lgamma_rf16_u10_intrin
#define xtgammaf_u1 Sleef_tgammaf16_u10_intrin
#define xerff_u1 Sleef_erff16_u10_intrin
#define xerfcf_u15 Sleef_erfcf16_u15_intrin
/***********************/
#define xlog1p_fast Sleef_log1p_fast_d8_u10_intrin
#define xlog1pf_fast Sleef_log1p_fast_f16_u10_intrin

#define xpown Sleef_pownd8_u10_intrin
#define xpownf Sleef_pownf16_u10_intrin
#define xpowr Sleef_powrd8_u10_intrin
#define xpowrf Sleef_powrf16_u10_intrin
